SoyutNet logo
-------------

.. image:: _static/soyutnet_logo.png
   :width: 128

SoyutNet logo is based on `<https://github.com/EmojiTwo/emojitwo/blob/master/svg_bw/1f914.svg>`_
of `Emojitwo <https://emojitwo.github.io/>`_, which is originally released as
`Emojione 2.2 <https://www.emojione.com>`_ by `Ranks.com <http://www.ranks.com>`_
with contributions from the Emojitwo community. It is licensed under
`CC-BY 4.0 <https://creativecommons.org/licenses/by/4.0/legalcode>`_.
